% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/definefuns.R
\name{paprox}
\alias{paprox}
\title{Calculating P-approximation coefficients}
\usage{
paprox(stock, sdot, dsdotds, dwds, aproxspace)
}
\arguments{
\item{stock}{An array of stock, \eqn{s}}

\item{sdot}{An array of ds/dt, \eqn{\dot{s}=\frac{ds}{dt}}}

\item{dsdotds}{An array of d(sdot)/ds, \eqn{\frac{d \dot{s}}{d s}}}

\item{dwds}{An array of dw/ds, \eqn{\frac{dW}{ds}}}

\item{aproxspace}{An approximation space defined by \code{aproxdef} function}
}
\value{
A list of approximation resuts: deg, lb, ub, delta, and coefficients
}
\description{
The function provides the P-approximation coefficients of the defined Chebyshev polynomials in \code{aproxdef}.
             For now, only unidimensional case is developed.
}
\details{
The P-approximation is finding the shadow price of a stock, \eqn{p} from the relation:\cr
\cr
\eqn{p(s) = \frac{W_{s}(s) + \dot{p}(s)}{\delta - \dot{s}_{s}}}, \cr
\cr
where \eqn{W_{s} = \frac{dW}{ds}}, \eqn{ \dot{p}(s) = \frac{dp}{ds}},
\eqn{\dot{s}_{s} = \frac{d\dot{s}}{ds} }, and \eqn{\delta} is the given discount rate.\cr
\cr
Consider approximation \eqn{p(s) = \mathbf{\mu}(s)\mathbf{\beta}}, \eqn{\mathbf{\mu}(s)}
is Chebyshev polynomials and \eqn{\mathbf{\beta}} is their coeffcients.
Then, \eqn{\dot{p} = \mathbf{\mu}_{s}(s)\mathbf{\beta}} by the orthogonality of Chebyshev basis.
Adopting the properties above, we can get the unknown coefficient vector \eqn{\beta} from:\cr
\cr
\eqn{\mathbf{\mu}\mathbf{\beta} = \left( W_{s} + \dot{s} \mathbf{\mu}_{s} \mathbf{\beta} \right)
\left( \delta - \dot{s}_{s} \right)^{-1} }, and thus, \cr
\cr
\eqn{\mathbf{\beta} = \left( \delta \mathbf{\mu} - \dot{s}_{s} \mathbf{\mu} - \dot{s} \mathbf{\mu}_{s} \right)^{-1} W_{s} }.\cr
\cr
#' In a case of over-determined (more nodes than approaximation degrees),\cr
\cr
\eqn{\left( \left( \delta \mathbf{\mu} - \dot{s}_{s} \mathbf{\mu} - \dot{s} \mathbf{\mu}_{s} \right)^{T}
\left( \delta \mathbf{\mu} - \dot{s}_{s} \mathbf{\mu} - \dot{s} \mathbf{\mu}_{s} \right) \right)^{-1}
\left( \delta \mathbf{\mu} - \dot{s}_{s} \mathbf{\mu} - \dot{s} \mathbf{\mu}_{s} \right)^{T} W_{s}} \cr
\cr
For more detils see Fenichel and Abbott (2014) and Fenichel et al. (2016).
}
\examples{
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("reefdata")
st <- reefaproxdata[,1]
sdot <- reefaproxdata[,2]
dsdotds <- reefaproxdata[,3]
dwds <- reefaproxdata[,6]
aproxdeg <- 50
lower <- 5*10^6
upper <- 359016000
delta <- 0.02
reefspace <- aproxdef(aproxdeg,lower,upper,delta)
paproxc <- paprox(st,sdot,dsdotds,dwds,reefspace)
}
\references{
Fenichel, Eli P. and Joshua K. Abbott. (2014) "\href{http://www.journals.uchicago.edu/doi/abs/10.1086/676034}{Natural Capital: From Metaphor to Measurement}."
             \emph{Journal of the Association of Environmental Economists}. 1(1/2):1-27.
}
\seealso{
\code{\link{aproxdef},\link{psim}}
}

